==> V01.38.zip: tweet_live-V01.38/web/2011-2012-museo-contribution/config.php <==
<?php
$config = array(
   	'hashtag'    => '#museoweb',
   	'date'   	 => '14.02.2012',
   	'heure'   	 => '17h00-20h00',
   	'place'   	 => 'Centre Pompidou (Paris)',
   	'duration'   => '',

   	'title' 	 => "Muséologie, muséographie et nouvelles formes d’adresse au public",
						
   	'abstract'   => "«&nbsp;<b>Comment la dynamique de contribution peut-elle converger avec l’indexation et la numérisation mise en place par les Musées ?</b>&nbsp;» <br/> 14 / 12 / 2012 de 17h00 à 20h00 @ Centre Pompidou (Paris)",

   	'description'=> "<p><b>Comment la dynamique de contribution peut-elle converger avec l’indexation et la numérisation mise en place par les Musées ?</b> (le 14/12/2012)</p>
<p>Quelle autorité ? Quel rapport au temps et notamment pour la recherche ? Les communautés intermédiaires ? Quelles stratégies et pour quel public ? Comment mettre en place les outils de la convergence ? Question de l’autorité en interne ou externe : les médiateurs, les conservateurs ? La question objectivité/subjectivité.</p>
<ul>
    <li>Maxime Crépel – Sciences Po</li>
    <li>Patrick Peccatte, Flickr Commons – SoftExperience</li>
    <li>Romain Wenz, data.bnf.fr et la notion d’autorité et d’identifiant dans l’écosystème du Web – BNF</li>
</ul>
<p>Coups de projecteur :</p>
<ul>
    <li>Pascal Krajewski – Fonds Trutat, Bibliothèque de Toulouse</li>
    <li>Jean-Frédéric Berthelot – Wikimédia</li>
    <li>François Queré et Renaud Sagot – Plateforme collaborative de la Cité de l’immigration</li>
</ul>",

   	'link' 		 => 'http://www.iri.centrepompidou.fr/evenement/museologie-museographie-et-nouvelles-formes-dadresse-au-public/?lang=fr_fr',
   	'islive'     => true,
   	'keywords'   => 'muséographie, muséologie, contribution, indexation, numérisation, communautés, recherche, médiation',
   	'rep' 		 => basename(__DIR__),
   	'partenaires'=> "<a href='http://www.culture.gouv.fr/'
class='footerLink' target='_blank'> Ministère de la Culture et communication </a>
|  <a href='http://www.iri.centrepompidou.fr/' class='footerLink' target='_blank'>
IRI  </a>",

    'client_visual' => "images/big_visuel_museo_2011_fr.png", // 501 × 376 pixels
    
 	'head_logo' => 'images/head_logo.gif', // 171 × 63 pixels
 	
  	'slide_background' => "images/slide4_museo_fr.png", // 606 × 282 pixels
    
  	'archive_img' => "images/museo-2011.jpg", // 270 × 150 pixels

 	'archive_title' => "Muséologie 2011 - Comment la dynamique de contribution peut-elle converger avec l’indexation et la numérisation mise en place par les Musées ?",
 	'archive_description' => "par <a href=\"http://www.iri.centrepompidou.fr/\" target=\"_blank\">IRI</a> au Centre Pompidou<br/> le mardi 14 février 2012 | 17:00 - 20:00",

    // After the event
	'metadata'		=> "http://www.iri.centrepompidou.fr/dev/ldt/ldtplatform/ldt/cljson/id/321ae0b0-ff2c-11e0-95c2-00145ea49a02",
	'duration'  	=> 10876600,
	'player'        => "res/metadataplayer/src/js/LdtPlayer.js",
	'div_height'    => 740,
	'player_width'  => 650,
	'player_height' => 500,
);

==> V01.77.zip: tweet_live-V01.77/web/2011-2012-museo-contribution/config.php <==
<?php
$config = array(
   	'hashtag'    => '#museoweb',
   	'date'   	 => '14.02.2012',
   	'heure'   	 => '17h00-20h00',
   	'place'   	 => 'Centre Pompidou (Paris)',
   	'duration'   => '',

   	'title' 	 => "Muséologie, muséographie et nouvelles formes d’adresse au public",
						
   	'abstract'   => "«&nbsp;<b>Comment la dynamique de contribution peut-elle converger avec l’indexation et la numérisation mise en place par les Musées ?</b>&nbsp;» <br/> 14 / 02 / 2012 de 17h00 à 20h00 @ Centre Pompidou (Paris)",

   	'description'=> "<p><b>Comment la dynamique de contribution peut-elle converger avec l’indexation et la numérisation mise en place par les Musées ?</b> (le 14/02/2012)</p>
<p>Quelle autorité ? Quel rapport au temps et notamment pour la recherche ? Les communautés intermédiaires ? Quelles stratégies et pour quel public ? Comment mettre en place les outils de la convergence ? Question de l’autorité en interne ou externe : les médiateurs, les conservateurs ? La question objectivité/subjectivité.</p>
<ul>
    <li>Maxime Crépel – Sciences Po</li>
    <li>Patrick Peccatte, Flickr Commons – SoftExperience</li>
    <li>Romain Wenz, data.bnf.fr et la notion d’autorité et d’identifiant dans l’écosystème du Web – BNF</li>
</ul>
<p>Coups de projecteur :</p>
<ul>
    <li>Pascal Krajewski – Fonds Trutat, Bibliothèque de Toulouse</li>
    <li>Jean-Frédéric Berthelot – Wikimédia</li>
    <li>François Queré et Renaud Sagot – Plateforme collaborative de la Cité de l’immigration</li>
</ul>",

   	'link' 		 => 'http://www.iri.centrepompidou.fr/evenement/museologie-museographie-et-nouvelles-formes-dadresse-au-public/?lang=fr_fr',
   	'islive'     => true,
   	'keywords'   => 'muséographie, muséologie, contribution, indexation, numérisation, communautés, recherche, médiation',
   	'rep' 		 => basename(__DIR__),
   	'partenaires'=> "<a href='http://www.culture.gouv.fr/'
class='footerLink' target='_blank'> Ministère de la Culture et communication </a>
|  <a href='http://www.iri.centrepompidou.fr/' class='footerLink' target='_blank'>
IRI  </a>",

    'client_visual' => "images/big_visuel_museo_2011_fr.png", // 501 × 376 pixels
    
 	'head_logo' => 'images/head_logo.gif', // 171 × 63 pixels
 	
  	'slide_background' => "images/slide4_museo_fr.png", // 606 × 282 pixels
    
  	'archive_img' => "images/museo-2011.jpg", // 270 × 150 pixels

 	'archive_title' => "Muséologie 2011 - Comment la dynamique de contribution peut-elle converger avec l’indexation et la numérisation mise en place par les Musées ?",
 	'archive_description' => "par <a href=\"http://www.iri.centrepompidou.fr/\" target=\"_blank\">IRI</a> au Centre Pompidou<br/> le mardi 14 février 2012 | 17:00 - 20:00",

    // After the event
	'metadata'		=> "http://ldt.iri.centrepompidou.fr/ldtplatform/ldt/cljson/id/fc62350e-69d9-11e1-9089-00145ea4a2be",
	'duration'  	=> 10876600,
	'player'        => "res/metadataplayer/src/js/LdtPlayer.js",
	'div_height'    => 740,
	'player_width'  => 650,
	'player_height' => 500,
);
